package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcTechnicalPlanMapper;
import com.ruoyi.oa.domain.CmcTechnicalPlan;
import com.ruoyi.oa.service.ICmcTechnicalPlanService;

/**
 * cmc技术方案Service业务层处理
 * 
 * @author cmc
 * @date 2024-04-02
 */
@Service
public class CmcTechnicalPlanServiceImpl implements ICmcTechnicalPlanService 
{
    @Autowired
    private CmcTechnicalPlanMapper cmcTechnicalPlanMapper;

    /**
     * 查询cmc技术方案
     * 
     * @param technicalPlanId cmc技术方案主键
     * @return cmc技术方案
     */
    @Override
    public CmcTechnicalPlan selectCmcTechnicalPlanByTechnicalPlanId(String technicalPlanId)
    {
        return cmcTechnicalPlanMapper.selectCmcTechnicalPlanByTechnicalPlanId(technicalPlanId);
    }

    /**
     * 查询cmc技术方案列表
     * 
     * @param cmcTechnicalPlan cmc技术方案
     * @return cmc技术方案
     */
    @Override
    public List<CmcTechnicalPlan> selectCmcTechnicalPlanList(CmcTechnicalPlan cmcTechnicalPlan)
    {
        return cmcTechnicalPlanMapper.selectCmcTechnicalPlanList(cmcTechnicalPlan);
    }

    /**
     * 新增cmc技术方案
     * 
     * @param cmcTechnicalPlan cmc技术方案
     * @return 结果
     */
    @Override
    public int insertCmcTechnicalPlan(CmcTechnicalPlan cmcTechnicalPlan)
    {
        return cmcTechnicalPlanMapper.insertCmcTechnicalPlan(cmcTechnicalPlan);
    }

    /**
     * 修改cmc技术方案
     * 
     * @param cmcTechnicalPlan cmc技术方案
     * @return 结果
     */
    @Override
    public int updateCmcTechnicalPlan(CmcTechnicalPlan cmcTechnicalPlan)
    {
        return cmcTechnicalPlanMapper.updateCmcTechnicalPlan(cmcTechnicalPlan);
    }

    /**
     * 批量删除cmc技术方案
     * 
     * @param technicalPlanIds 需要删除的cmc技术方案主键
     * @return 结果
     */
    @Override
    public int deleteCmcTechnicalPlanByTechnicalPlanIds(String[] technicalPlanIds)
    {
        return cmcTechnicalPlanMapper.deleteCmcTechnicalPlanByTechnicalPlanIds(technicalPlanIds);
    }

    /**
     * 删除cmc技术方案信息
     * 
     * @param technicalPlanId cmc技术方案主键
     * @return 结果
     */
    @Override
    public int deleteCmcTechnicalPlanByTechnicalPlanId(String technicalPlanId)
    {
        return cmcTechnicalPlanMapper.deleteCmcTechnicalPlanByTechnicalPlanId(technicalPlanId);
    }
}
